PoissonKernelTest
=================

.. currentmodule:: QuadratiK.poisson_kernel_test

.. autoclass:: PoissonKernelTest

.. rubric:: Methods

.. autosummary::
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
        PoissonKernelTest.stats
    
    
    
        PoissonKernelTest.summary
    
    
    
        PoissonKernelTest.test
    
    

----





.. automethod:: PoissonKernelTest.stats



.. automethod:: PoissonKernelTest.summary



.. automethod:: PoissonKernelTest.test



.. raw:: html

     <div style='clear:both'></div>